# Prepare the workspace ----

# Clean the workspace
rm(list=ls()) 

# Free Unused R memory
gc()

# Options for avoid scientific notation
options(scipen = 9999)

# Set the same seed
set.seed(123)

# Loading the packages

# list of package needed
packages <- c( 
  "stringr",     # String manipulation
  "stringi",     # String manipulation
  "dplyr",       # Data manipulation
  "data.table",  # Data manipulation
  "ggplot2",     # Data visualization
  "lubridate",    # Date and time manipulation
  "tictoc"
)

# If the package is not installed, then install it 
if (!require("pacman")) install.packages("pacman")

# Load the packages 
pacman::p_load(packages, character.only = TRUE, install = TRUE)

tic()
# Setting Working Directories ----

one_drive  <- "./.."

# Data Repositories
raw_data <- file.path(one_drive, "Data/Raw")
int_data <- file.path(one_drive, "Data/Intermediate")
fin_data <- file.path(one_drive, "Data/Final")

# Outputs
graph_output <- file.path(one_drive, "Outputs/Graphs")
table_output <- file.path(one_drive, "Outputs/Tables")

# CODE
# function_code <- file.path(one_drive, "Code/Functions")
scripts_code  <- file.path(one_drive, "Code")

# Master scripts ----

# Run first code for loading and cleaning 
source(file.path(scripts_code, "1_clean.R"))

# 2. Render the Quarto file
rmarkdown::render(file.path(scripts_code, "2_Devolve_ReportResults.qmd"), output_format = "all")

#  Notify user when the process is complete
cat("Reproducibility package complete! All outputs generated.\n")

toc()
