# Load the data ----

# Full panel + fixed characteristics
data_full = fread(file.path(raw_data, "Devolve_WB_20230423_Hash.csv"))
data_familysize =  fread(file.path(raw_data, "Devolve_WB_Moradores_20240626_Hash.csv"))

# 2. Clean Panel Data----

#This datasets creates a simplified ID, so we don;t have to carry has during analyses
hash_walthrough = data_full %>% unique(by = 'hash_cpf') %>% 
  select(hash_cpf) %>% 
  arrange(hash_cpf) %>% 
  mutate(unique_id = 1:n())

#This dataset stores fixed characteristics of individuals
data_fixed = data_full%>% unique(by = 'hash_cpf') %>% 
  .[,hash_cpf:yind_nfg] %>% 
  left_join(hash_walthrough, by = 'hash_cpf') %>% 
  mutate(yind_ativo_devolve = ifelse(yind_ativo_devolve == "S", 1, 0)) # Si and No == 1 and 0

#This is the panel data, with no fixed characteristics
data_panel = data_full %>% select(hash_cpf, xnro_anomes_ref:xvlr_dev_total) %>% 
  left_join(hash_walthrough, by = 'hash_cpf') %>% 
  select(-hash_cpf) %>% 
  select(unique_id, everything()) %>% 
  mutate(ano_ref = as.numeric(substr(xnro_anomes_ref, 1, 4)),
         mes_ref = as.numeric(substr(xnro_anomes_ref, 5, 6))) %>% 
  arrange(unique_id, ano_ref, mes_ref)

#Add family size to fixed characteristics dataset
data_fixed = data_fixed %>% 
  left_join(data_familysize, by = 'hash_cpf') %>% 
  select(-hash_cpf)

# save the dataset for household level
saveRDS(data_fixed, file.path(int_data, "data_fixed.RDS"))

# save the dataset for the panel
saveRDS(data_panel, file.path(int_data, "data_panel.RDS"))
